==> haskell-path-0.6.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path
version: 0.6.1
id: path-0.6.1-3vYPgWREPZf5twNYNrl9DA
key: path-0.6.1-3vYPgWREPZf5twNYNrl9DA
license: BSD3
copyright: 2015–2017 FP Complete
maintainer: Chris Done <chrisdone@fpcomplete.com>
synopsis: Support for well-typed paths
description:
    Support for well-typed paths.
category: System, Filesystem
author: Chris Done <chrisdone@fpcomplete.com>
exposed: True
indefinite: False
exposed-modules:
    Path Path.Internal
abi: 967c6fc66e18bdd5d02c19e49d63a914
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/path-0.6.1
hs-libraries: HSpath-0.6.1-3vYPgWREPZf5twNYNrl9DA
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0 deepseq-1.4.3.0
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk template-haskell-2.12.0.0
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=5e6b7bed78b23d60beb18bffc251a955
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             deepseq-1.4.3.0=5db6f9c28d6213bd6646f988460dacd0
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
haddock-interfaces: /usr/share/doc/haskell-path/html/path.haddock
haddock-html: /usr/share/doc/haskell-path/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.6.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path
version: 0.6.1
id: path-0.6.1-F7dXkjr3RauIWw3mbJNf6I
key: path-0.6.1-F7dXkjr3RauIWw3mbJNf6I
license: BSD3
copyright: 2015–2017 FP Complete
maintainer: Chris Done <chrisdone@fpcomplete.com>
synopsis: Support for well-typed paths
description:
    Support for well-typed paths.
category: System, Filesystem
author: Chris Done <chrisdone@fpcomplete.com>
exposed: True
indefinite: False
exposed-modules:
    Path Path.Internal
abi: b260cf17ae64acbad42ed16ce9b4876a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/path-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/path-0.6.1
hs-libraries: HSpath-0.6.1-F7dXkjr3RauIWw3mbJNf6I
depends:
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq base-4.10.0.0 deepseq-1.4.3.0
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 filepath-1.4.1.2
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk template-haskell-2.12.0.0
abi-depends: aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=66a2d17fbbc7a6e96ce7fb88add84f33
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             deepseq-1.4.3.0=5db6f9c28d6213bd6646f988460dacd0
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
haddock-interfaces: /usr/share/doc/haskell-path/html/path.haddock
haddock-html: /usr/share/doc/haskell-path/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
